@@ -6,7 +6,18 @@ import os, sys
 
 BUILD_LANGS = [
     'en', # base strings
-    'de', 'es', 'fi', 'fr', 'ia', 'ie', 'ru', 'sr', 'tok', 'zh_Hans', 'zh_Hant'
+    'de',
+    'es',
+    'fi',
+    'fr',
+    'ia',
+    'ie',
+    'pl',
+    'ru',
+    'sr',
+    'tok',
+    'zh_Hans',
+    'zh_Hant'
 ]
 MODE = 'compile'
 ESCAPES = {
